@@ -5,7 +5,7 @@ use strict;
 
 BEGIN {
 	$HTML::HTML5::Parser::UA::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::HTML5::Parser::UA::VERSION   = '0.207_01';
+	$HTML::HTML5::Parser::UA::VERSION   = '0.202';
 }
 
 use Encode qw(decode);
@@ -26,17 +26,13 @@ sub get
 		{ goto \&_get_lwp }
 	if ($uri =~ /^file:/i)
 		{ goto \&_get_fs }
-
+	
 	goto \&_get_tiny;
 }
 
 sub _get_lwp
 {
-	eval "require LWP::UserAgent; 1"
-	or do {
-		require Carp;
-		Carp::croak("could not load LWP::UserAgent");
-	};
+	require LWP::UserAgent;
 	
 	my ($class, $uri, $ua) = @_;
 
@@ -100,8 +96,7 @@ sub _get_tiny
 		};
 	}
 	
-	$response->{decoded_content} = $response->{content}
-		unless defined $response->{decoded_content};
+	$response->{decoded_content} //= $response->{content};
 	return $response;
 }
 
@@ -120,17 +115,17 @@ sub _get_fs
 			{ (200 => 'OK') }
 	};
 	
-	$content ||= do {
+	$content //= do {
 		if (open my $fh, '<', $file)
 			{ local $/ = <$fh> }
 		else
 			{ $status = 418; $reason = "I'm a teapot"; $content_type = 'text/plain'; $! }
 	};
 	
-	$content_type ||= 'text/xml' if $file =~ /\.xml$/i;
-	$content_type ||= 'application/xhtml+xml' if $file =~ /\.xht(ml)?$/i;
-	$content_type ||= 'text/html' if $file =~ /\.html?$/i;
-	$content_type ||= 'application/octet-stream';
+	$content_type //= 'text/xml' if $file =~ /\.xml$/i;
+	$content_type //= 'application/xhtml+xml' if $file =~ /\.xht(ml)?$/i;
+	$content_type //= 'text/html' if $file =~ /\.html?$/i;
+	$content_type //= 'application/octet-stream';
 	
 	return +{
 		success  => ($status == 200),
